@@ -696,7 +696,7 @@ var FCKDomTools =
 
 	SetElementMarker : function ( markerObj, element, attrName, value)
 	{
-		var id = String( parseInt( Math.random() * 0xfffffff, 10 ) ) ;
+		var id = String( parseInt( Math.random() * 0xffffffff, 10 ) ) ;
 		element._FCKMarkerId = id ;
 		element[attrName] = value ;
 		if ( ! markerObj[id] )
@@ -972,8 +972,9 @@ var FCKDomTools =
 	},
 
 	/**
-	 * Current implementation for ScrollIntoView (due to #1462). We don't have
-	 * a complete implementation here, just the things that fit our needs.
+	 * Current implementation for ScrollIntoView (due to #1462 and #2279). We
+	 * don't have a complete implementation here, just the things that fit our
+	 * needs.
 	 */
 	ScrollIntoView : function( element, alignTop )
 	{
@@ -988,22 +989,21 @@ var FCKDomTools =
 		// Appends the height it we are about to align the bottoms.
 		if ( alignTop === false )
 		{
-			offset += element.offsetHeight ;
+			offset += element.offsetHeight || 0 ;
 
 			// Consider the margin in the scroll, which is ok for our current
 			// needs, but needs investigation if we will be using this function
 			// in other places.
-			offset += parseInt( this.GetCurrentElementStyle( element, 'marginBottom' ) || 0, 10 ) ;
+			offset += parseInt( this.GetCurrentElementStyle( element, 'marginBottom' ) || 0, 10 ) || 0 ;
 		}
 
 		// Appends the offsets for the entire element hierarchy.
-		offset += element.offsetTop ;
-		while ( ( element = element.offsetParent ) )
-			offset += element.offsetTop || 0 ;
+		var elementPosition = FCKTools.GetDocumentPosition( window, element ) ;
+		offset += elementPosition.y ;
 
 		// Scroll the window to the desired position, if not already visible.
 		var currentScroll = FCKTools.GetScrollPosition( window ).Y ;
-		if ( offset > 0 && offset > currentScroll )
+		if ( offset > 0 && ( offset > currentScroll || offset < currentScroll - windowHeight ) )
 			window.scrollTo( 0, offset ) ;
 	},
 
@@ -1020,5 +1020,38 @@ var FCKDomTools =
 
 		// In the DTD # == text node.
 		return ( childDTD['#'] && !FCKListsLib.NonEditableElements[ nodeName ] ) ;
+	},
+
+	GetSelectedDivContainers : function()
+	{
+		var currentBlocks = [] ;
+		var range = new FCKDomRange( FCK.EditorWindow ) ;
+		range.MoveToSelection() ;
+
+		var startNode = range.GetTouchedStartNode() ;
+		var endNode = range.GetTouchedEndNode() ;
+		var currentNode = startNode ;
+
+		if ( startNode == endNode )
+		{
+			while ( endNode.nodeType == 1 && endNode.lastChild )
+				endNode = endNode.lastChild ;
+			endNode = FCKDomTools.GetNextSourceNode( endNode ) ;
+		}
+
+		while ( currentNode && currentNode != endNode )
+		{
+			if ( currentNode.nodeType != 3 || !/^[ \t\n]*$/.test( currentNode.nodeValue ) )
+			{
+				var path = new FCKElementPath( currentNode ) ;
+				var blockLimit = path.BlockLimit ;
+				if ( blockLimit && blockLimit.nodeName.IEquals( 'div' ) && currentBlocks.IndexOf( blockLimit ) == -1 )
+					currentBlocks.push( blockLimit ) ;
+			}
+
+			currentNode = FCKDomTools.GetNextSourceNode( currentNode ) ;
+		}
+
+		return currentBlocks ;
 	}
 } ;
