@@ -33,10 +33,10 @@
 // |                                                                           |
 // +---------------------------------------------------------------------------+
 //
-// $Id: lib-comment.php,v 1.65 2008/05/23 10:50:50 dhaun Exp $
+// $Id: lib-comment.php,v 1.69 2008/09/21 08:37:11 dhaun Exp $
 
-if (strpos ($_SERVER['PHP_SELF'], 'lib-comment.php') !== false) {
-    die ('This file can not be used on its own!');
+if (strpos(strtolower($_SERVER['PHP_SELF']), 'lib-comment.php') !== false) {
+    die('This file can not be used on its own!');
 }
 
 if( $_CONF['allow_user_photo'] )
@@ -93,7 +93,10 @@ function CMT_commentBar( $sid, $title, $type, $order, $mode, $ccode = 0 )
 
     $cmt_title = stripslashes($title);
     $commentbar->set_var('story_title', $cmt_title);
-    $cmt_title = htmlspecialchars($cmt_title);
+    // Article's are pre-escaped.
+    if( $type != 'article' ) {
+        $cmt_title = htmlspecialchars($cmt_title);
+    }
     $commentbar->set_var('comment_title', $cmt_title);
 
     if( $type == 'article' ) {
@@ -214,6 +217,7 @@ function CMT_commentBar( $sid, $title, $type, $order, $mode, $ccode = 0 )
 function CMT_getComment( &$comments, $mode, $type, $order, $delete_option = false, $preview = false, $ccode = 0 )
 {
     global $_CONF, $_TABLES, $_USER, $LANG01, $MESSAGE, $_IMAGE_TYPE;
+    global $CUSTOM_MOBILE_UA;  // add geeklog-jp
 
     $indent = 0;  // begin with 0 indent
     $retval = ''; // initialize return value
@@ -323,7 +327,7 @@ function CMT_getComment( &$comments, $mode, $type, $order, $delete_option = fals
             $template->set_var( 'end_author_anchortag', '</a>' );
             $template->set_var( 'author_link',
                 COM_createLink(
-                    $A['username'],
+                    $fullname,
                     $_CONF['site_url'] . '/users.php?mode=profile&amp;uid=' . $A['uid']
                 )
             );
@@ -425,9 +429,13 @@ function CMT_getComment( &$comments, $mode, $type, $order, $delete_option = fals
         // create a reply to link
         $reply_link = '';
         if( $ccode == 0 ) {
+            $a_title = $A['title'];
+            if ( $CUSTOM_MOBILE_UA > 1 ) {
+                $a_title = mb_convert_encoding($A['title'], 'SJIS-win');
+            }
             $reply_link = $_CONF['site_url'] . '/comment.php?sid=' . $A['sid']
                         . '&amp;pid=' . $A['cid'] . '&amp;title='
-                        . urlencode( $A['title'] ) . '&amp;type=' . $A['type'];
+                        . urlencode( $a_title ) . '&amp;type=' . $A['type'];
             $reply_option = COM_createLink($LANG01[43], $reply_link ) . ' | ';
             $template->set_var( 'reply_option', $reply_option );
         } else {
@@ -719,7 +727,8 @@ function CMT_commentForm($title,$comment,$sid,$pid='0',$type,$mode,$postmode)
             $newcomment = $comment;
             if (!empty ($sig)) {
                 if (($postmode == 'html') || ($fakepostmode == 'html')) {
-                    $newcomment .= '<p>---<br' . XHTML . '>' . nl2br ($sig);
+                    $newcomment .= '<p>---<br' . XHTML . '>' . nl2br($sig)
+                                . '</p>';
                 } else {
                     $newcomment .= LB . LB . '---' . LB . $sig;
                 }
@@ -749,9 +758,9 @@ function CMT_commentForm($title,$comment,$sid,$pid='0',$type,$mode,$postmode)
                     }
                 }
 
-                if (empty ($A['username'])) {
-                    $A['username'] = DB_getItem ($_TABLES['users'], 'username',
-                                                 "uid = $uid");
+                if (empty($A['username']) || empty($A['fullname']) || empty($A['email'])) {
+                    $nresult = DB_query("SELECT username, fullname, email FROM {$_TABLES['users']} WHERE uid = $uid");
+                    list($A['username'], $A['fullname'], $A['email']) = DB_fetchArray($nresult);
                 }
                 $thecomments = CMT_getComment ($A, 'flat', $type, 'ASC', false,
                                                true);
@@ -920,7 +929,7 @@ function CMT_saveComment ($title, $comment, $sid, $pid, $type, $postmode)
     }
     if (!empty ($sig)) {
         if ($postmode == 'html') {
-            $comment .= '<p>---<br' . XHTML . '>' . nl2br($sig);
+            $comment .= '<p>---<br' . XHTML . '>' . nl2br($sig) . '</p>';
         } else {
             $comment .= LB . LB . '---' . LB . $sig;
         }
